!!! important
    Before you can install napari-micromorph, you need to have a working [napari](https://napari.org/stable/) installation. Please refer to the [installation guide](https://napari.org/stable/tutorials/fundamentals/installation.html#napari-installation) before continuing.

## Install as Python package
If you have installed napari by creating an environment, you can install napari-micromorph by running the command
```pip install napari-micromorph```. This will install both the `micromorph` and `napari-micromorph` packages, and will enable you to also use `micromorph` in scripts and jupyter notebooks if you later prefer to do so.

If the installation has been successful, you will be able to start a napari instance with the plugin pre-loaded by running:
```napari-micromorph```


## Install from napari plugin interface
If you would like a command-line-free experience, you can do so by launching napari, then clicking on `Plugins > Install/Uninstall Plugins...` and looking for `napari-micromorph`. After that you can click on the "Install" button and everything will be installed for you. You should close and re-launch napari after the installation is complete.

You can check the installation has been successful by launching napari and checking that the plugin appears in the Plugins dropdown menu.